==> nextcloud-app-notes-3.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/pt_BR.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "The last viewed note cannot be accessed. " : "A última nota visualizada não pode ser acessada.",
    "The notes folder is not accessible: %s" : "A pasta de notas não está acessível: %s",
    "Error" : "Erro",
    "New note" : "Nova nota",
    "Distraction-free notes and writing" : "Notas e escrita sem distração",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "O aplicativo Notes é um aplicativo de anotações livre de distrações para o [Nextcloud](https://www.nextcloud.com/). Suporta categorias para uma melhor organização e formatação usando a sintaxe [Markdown](https://en.wikipedia.org/wiki/Markdown). As notas são salvas como arquivos em seu Nextcloud, para que você possa visualizá-las e editá-las com qualquer cliente Nextcloud. Além disso, uma [REST API]docs/api/README.md separada permite uma fácil integração com aplicativos de terceiros (atualmente, há aplicativos de notas para [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) e [console](https://git.danielmoch.com/nncli/about) que permitem acesso conveniente às suas anotações do Nextcloud). Outros recursos incluem notas de marcação como favoritos.",
    "Settings" : "Configurações",
    "Deleted {title}" : "{title} excluído",
    "Deleted {number} notes" : "{number} anotações excluídas",
    "Undo Delete" : "Desfazer Exclusão",
    "Please chose a valid path in {label} (bottom left corner)." : "Escolha um caminho válido em {label} (canto inferior esquerdo).",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Existem anotações não salvas. Saindo da página elas serão perdidas!",
    "Folder to store your notes" : "Pasta para armazenar anotações",
    "path to notes" : "caminho para notas",
    "File extension for new notes" : "Extensão de arquivo para novas anotações",
    "All notes" : "Todas as notas",
    "Categories" : "Categorias",
    "No search result for “{search}” in {category}" : "Nenhum resultado para pesquisa de \"{search}\" em {category}",
    "No search result for “{search}”" : "Nenhum resultado de pesquisa para \"{search}\"",
    "Loading …" : "Carregando...",
    "Search result for “{search}” in {category}" : "Resultado da pesquisa para \"{search}\" em {category}",
    "Search result for “{search}”" : "Resultado da pesquisa para \"{search}\"",
    "Today" : "Hoje",
    "Yesterday" : "Ontem",
    "This week" : "Esta semana",
    "Last week" : "Última semana",
    "This month" : "Este mês",
    "Last month" : "Último mês",
    "Rename" : "Renomear",
    "Note's title" : "Título da anotação",
    "Delete note" : "Excluir anotação",
    "Remove from favorites" : "Remover dos favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "Error during preparing note for deletion." : "Erro ao preparar anotação para exclusão.",
    "Empty note" : "Anotação vazia",
    "Write …" : "Escrever...",
    "Details" : "Detalhes",
    "Preview" : "Pré-visualização",
    "Edit" : "Editar",
    "Exit full screen" : "Sair da tela cheia",
    "Full screen" : "Tela cheia",
    "Save failed. Click to retry." : "Falha ao salvar. Clique para retentar.",
    "Set category" : "Definir categoria",
    "Category" : "Categoria",
    "Uncategorized" : "Sem categoria",
    "Click here to save manually" : "Clique aqui para salvar manualmente",
    "Saving failed!" : "Gravação falhou!",
    "Last modified: {date}" : "Última modificação: {date}",
    "Note has unsaved changes" : "A anotação tem alterações não salvas",
    "Subcategory" : "Subcategoria",
    "_%n word_::_%n words_" : ["%n palavra","%n palavras"],
    "Write down your thoughts without any distractions." : "Anote seus pensamentos sem distrações.",
    "Use Markdown markups to style your text." : "Use marcações Markdown para estilizar seu texto.",
    "Organize your notes in categories." : "Organize suas anotações em categorias.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instale o aplicativo em seu celular para acessar anotações a partir de qualquer lugar.",
    "Android app" : "Aplicativo Android",
    "iOS app" : "Aplicativo iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Comece a escrever uma anotação clicando em “{newnote}” na navegação do aplicativo.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Você pode criar subcategorias usando “/” como delimitador entre categoria pai e subcategoria, por.ex. “{parent}/{sub}”.",
    "See JavaScript console and server log for details." : "Veja o console JavaScript console e os logs do servidor para detalhes.",
    "Saving the note has failed due to insufficient storage." : "O salvamento da anotação falhou devido ao armazenamento insuficiente.",
    "Updating settings has failed." : "A atualização das configurações falhou.",
    "Fetching notes has failed." : "A busca de anotações falhou.",
    "Fetching note {id} has failed." : "A busca da anotação {id} falhou.",
    "Renaming note {id} has failed." : "Erro ao renomear a anotação {id}.",
    "Creating new note has failed." : "A criação de uma nova anotação falhou.",
    "Updating note {id} has failed." : "A atualização da anotação {id} falhou.",
    "Undo delete has failed for note {title}." : "Erro ao desfazer exclusão da anotação {title}.",
    "Deleting note {id} has failed." : "A exclusão da anotação {id} falhou.",
    "Toggling favorite for note {id} has failed." : "A alternância de favoritos para a anotação {id} falhou.",
    "Updating the note's category has failed. Is the target directory writable?" : "A atualização da categoria da nota falhou. O diretório de destino é gravável?",
    "Updating the category for note {id} has failed." : "A atualização da categoria da anotação {id} falhou.",
    "Development Mode" : "Modo de Desenvolvimento",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Parece que o aplicativo Notes foi instalado a partir de uma fonte de desenvolvimento. Ao invés disso, instale-o a partir da <a href=\"%1$s\">Loja de Aplicativos Nextcloud</a> oficial. Se deseja criar o aplicativo Notes você mesmo, siga as <a href=\"%2$s\">instruções do desenvolvedor</a>."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-notes-3.6.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/pt_BR.js <==
OC.L10N.register(
    "notes",
    {
    "Reading notes from filesystem has failed." : "Erro ao ler anotações do sistema de arquivos.",
    "Error" : "Erro",
    "New note" : "Nova nota",
    "Notes" : "Notas",
    "Distraction-free notes and writing" : "Notas e escrita sem distração",
    "Please see Nextcloud server log for details." : "Verifique os logs do servidor Nextcloud para detalhes.",
    "Deleted {title}" : "{title} excluído",
    "Deleted {number} notes" : "{number} anotações excluídas",
    "Undo Delete" : "Desfazer Exclusão",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Existem anotações não salvas. Saindo da página elas serão perdidas!",
    "Settings" : "Configurações",
    "Folder to store your notes" : "Pasta para armazenar anotações",
    "path to notes" : "caminho para notas",
    "File extension for new notes" : "Extensão de arquivo para novas anotações",
    "All notes" : "Todas as notas",
    "Categories" : "Categorias",
    "No search result for “{search}” in {category}" : "Nenhum resultado para pesquisa de \"{search}\" em {category}",
    "No search result for “{search}”" : "Nenhum resultado de pesquisa para \"{search}\"",
    "Loading …" : "Carregando...",
    "Search result for “{search}” in {category}" : "Resultado da pesquisa para \"{search}\" em {category}",
    "Search result for “{search}”" : "Resultado da pesquisa para \"{search}\"",
    "Today" : "Hoje",
    "Yesterday" : "Ontem",
    "This week" : "Esta semana",
    "Last week" : "Última semana",
    "This month" : "Este mês",
    "Last month" : "Último mês",
    "Rename" : "Renomear",
    "Note's title" : "Título da anotação",
    "Delete note" : "Excluir anotação",
    "Remove from favorites" : "Remover dos favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "Error during preparing note for deletion." : "Erro ao preparar anotação para exclusão.",
    "Empty note" : "Anotação vazia",
    "Write …" : "Escrever...",
    "Details" : "Detalhes",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editar",
    "Preview" : "Pré-visualização",
    "Exit full screen" : "Sair da tela cheia",
    "Full screen" : "Tela cheia",
    "Save failed. Click to retry." : "Falha ao salvar. Clique para retentar.",
    "Set category" : "Definir categoria",
    "Category" : "Categoria",
    "Uncategorized" : "Sem categoria",
    "Click here to save manually" : "Clique aqui para salvar manualmente",
    "Saving failed!" : "Gravação falhou!",
    "Last modified: {date}" : "Última modificação: {date}",
    "Note has unsaved changes" : "A anotação tem alterações não salvas",
    "Subcategory" : "Subcategoria",
    "_%n word_::_%n words_" : ["%n palavra","%n palavras"],
    "_%n character_::_%n characters_" : ["%n caractere","%n caracteres"],
    "Write down your thoughts without any distractions." : "Anote seus pensamentos sem distrações.",
    "Use Markdown markups to style your text." : "Use marcações Markdown para estilizar seu texto.",
    "Organize your notes in categories." : "Organize suas anotações em categorias.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instale o aplicativo em seu celular para acessar anotações a partir de qualquer lugar.",
    "Android app" : "Aplicativo Android",
    "iOS app" : "Aplicativo iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Comece a escrever uma anotação clicando em “{newnote}” na navegação do aplicativo.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Você pode criar subcategorias usando “/” como delimitador entre categoria pai e subcategoria, por.ex. “{parent}/{sub}”.",
    "Note not found." : "Anotação não encontrada.",
    "Note is locked." : "A anotação está bloqueada.",
    "Insufficient storage." : "Armazenamento insuficiente.",
    "See JavaScript console and server log for details." : "Veja o console JavaScript console e os logs do servidor para detalhes.",
    "Updating settings has failed." : "A atualização das configurações falhou.",
    "Error from Nextcloud server: {msg}" : "Erro do servidor Nextcloud: {msg}",
    "Fetching notes has failed." : "A busca de anotações falhou.",
    "Fetching note {id} has failed." : "A busca da anotação {id} falhou.",
    "Refreshing note {id} has failed." : "Erro na atualização da anotação {id}.",
    "Renaming note {id} has failed." : "Erro ao renomear a anotação {id}.",
    "Creating new note has failed." : "A criação de uma nova anotação falhou.",
    "Saving note {id} has failed." : "Erro ao salvar a nota {id}.",
    "Updating title for note {id} has failed." : "A atualização do título para a anotação {id} falhou.",
    "Undo delete has failed for note {title}." : "Erro ao desfazer exclusão da anotação {title}.",
    "Deleting note {id} has failed." : "A exclusão da anotação {id} falhou.",
    "Toggling favorite for note {id} has failed." : "A alternância de favoritos para a anotação {id} falhou.",
    "Updating the note's category has failed. Is the target directory writable?" : "A atualização da categoria da nota falhou. O diretório de destino é gravável?",
    "Updating the category for note {id} has failed." : "A atualização da categoria da anotação {id} falhou.",
    "Development Mode" : "Modo de Desenvolvimento",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Parece que o aplicativo Notes foi instalado a partir de uma fonte de desenvolvimento. Ao invés disso, instale-o a partir da <a href=\"%1$s\">Loja de Aplicativos Nextcloud</a> oficial. Se deseja criar o aplicativo Notes você mesmo, siga as <a href=\"%2$s\">instruções do desenvolvedor</a>."
},
"nplurals=2; plural=(n > 1);");
